@@ -2,7 +2,7 @@
 import argparse
 
 from mydot import Dotfiles
-from mydot.console import console, my_theme, rich_text
+from mydot.console import my_theme, rich_text
 
 
 rich_str = {
@@ -28,11 +28,14 @@ group = parser.add_mutually_exclusive_group()
 group.add_argument(
     "-e",
     "--edit",
-    help="Use fzf to interactively choose files to edit",
+    help="Use fzf to interactively choose file(s) to edit",
     action="store_true",
 )
 group.add_argument(
-    "-s", "--status", help="Show status of dotfiles repo", action="store_true"
+    "-s",
+    "--status",
+    help="Show status of dotfiles repo",
+    action="store_true",
 )
 group.add_argument(
     "-a",
@@ -46,19 +49,26 @@ group.add_argument(
     help="Show list of all files in the repo",
     action="store_true",
 )
+group.add_argument(
+    "-r",
+    "--restore",
+    help="Use fzf to interactively choose file(s) to remove from the staging area.",
+    action="store_true",
+)
 args = parser.parse_args()
-dfs = Dotfiles()
+dotfiles = Dotfiles()
 
 if args.edit:
-    dfs.edit_files()
+    dotfiles.edit_files()
 elif args.add:
-    adds = dfs.add()
-    # console.print(f"selected dotfiles = {adds}")
+    dotfiles.add_changes()
 elif args.status:
-    dfs.show_status()
+    dotfiles.show_status()
 elif args.list:
-    for dotfile in dfs.list_all:
+    for dotfile in dotfiles.list_all:
         print(dotfile)
+elif args.restore:
+    dotfiles.restore()
 else:
     parser.parse_args(["-h"])
 
